@@ -4,39 +4,59 @@
 //  $Id: mtc.cpp,v 1.1.1.1 2003/10/27 18:51:48 wschweer Exp $
 //
 //  (C) Copyright 2001 Werner Schweer (ws@seh.de)
+//
+//  This program is free software; you can redistribute it and/or
+//  modify it under the terms of the GNU General Public License
+//  as published by the Free Software Foundation; version 2 of
+//  the License, or (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+//
 //=========================================================
 
 #include "mtc.h"
+#include "sync.h"
 #include <stdio.h>
 
+namespace MusEGlobal {
 extern int mtcType;
+}
+
+namespace MusECore {
 
 //---------------------------------------------------------
-//   MTC::time
-//    converts MTC Time to seconds according to
+//   MTC::timeUS
+//    converts MTC Time to microseconds according to
 //    global mtcType
 //---------------------------------------------------------
 
-double MTC::time(int type) const
+uint64_t MTC::timeUS(int type) const
       {
-      double time = _h * 3600 + _m * 60 + _s;
-      double ft = 0.0;
+      uint64_t time = 1000000UL * (_h * 3600UL + _m * 60UL + _s);
+      uint64_t f = 10000UL * (_f * 100UL + _sf);
       if(type == -1)
-        type = mtcType;
+        type = MusEGlobal::mtcType;
       switch (type) {
             case 0:     // 24 frames sec
-                  ft = 1.0/24.0;
+                  time += f / 24UL;
                   break;
             case 1:     // 25
-                  ft = 0.04;
+                  time += f / 25UL;
                   break;
             case 2:     // 30 drop frame        TODO
             case 3:     // 30 non drop frame
             default:
-                  ft = 1.0/30.0;
+                  time += f / 30UL;
                   break;
             }
-      return time + ft *_f + 0.01 * ft * _sf;
+      return time;
       }
 
 //---------------------------------------------------------
@@ -53,7 +73,7 @@ MTC::MTC(double t, int type)
       t -= _s;
       double ft = 1.0/24.0;
       if(type == -1)
-        type = mtcType;
+        type = MusEGlobal::mtcType;
       switch (type) {
             case 0:     // 24 frames sec
                   ft = 1.0/24.0;
@@ -82,7 +102,7 @@ void MTC::incQuarter(int type)
       {
       int frames = 24;
       if(type == -1)
-        type = mtcType;
+        type = MusEGlobal::mtcType;
       switch (type) {
             case 0:
                   frames = 24;
@@ -128,3 +148,4 @@ void MTC::print() const
       }
 
 
+} // namespace MusECore
